
<p align="center" id='大礼包-banner'>
    <a target="_blank" href='http://python4office.cn/fuli/fuli-source-0726/'>
    <img src="https://banner-1300615378.cos.ap-guangzhou.myqcloud.com/%E6%A8%AA%E6%9D%A1/Python%E5%A4%A7%E7%A4%BC%E5%8C%85.jpg" width="100%"/>
    </a>   
</p>




<p align="center">
	👉 <a target="_blank" href="https://www.python-office.com/">项目官网：https://www.python-office.com/</a> 👈
</p>
<p align="center">
	👉 <a target="_blank" href="https://python-office-1300615378.cos.ap-chongqing.myqcloud.com/python-office.jpg">本开源项目的交流群</a> 👈
</p>
<p align="center" name="gitee">
  <a target="_blank" href='https://github.com/CoderWanFeng/pydatav'>
    <img src="https://img.shields.io/github/stars/CoderWanFeng/pydatav.svg?style=social" alt="github star"/>
    </a>
	<a target="_blank" href='https://gitee.com/CoderWanFeng/pydatav/'>
		<img src='https://gitee.com/CoderWanFeng/pydatav/badge/star.svg?theme=dark' alt='gitee star'/>
	</a>
  	<a href="https://mp.weixin.qq.com/s/yaSmFKO3RrBpyanW3nvRAQ">
	<img src="https://img.shields.io/badge/QQ-163434413-orange"/>
  </a>
    	<a href="https://mp.weixin.qq.com/s/NN2pX2bQPpczOeGF4ARNtw">
	<img src="https://img.shields.io/badge/%E5%BE%AE%E4%BF%A1-%E4%BA%A4%E6%B5%81%E7%BE%A4-brightgreen"/>
  </a>
  
</p>


# 项目运行

使用docker部署

```shell script
docker build .
docker run -it -p 8888:80 image-id
/usr/sbin/nginx
```

# 源码和演示


- 视频说明：https://www.bilibili.com/video/BV1Kz4y1r76w/

- 线上演示：https://python-office.com/pydatav/demo/

> 本项目所有案例采用的数据均属虚构，切勿当真！

- 模板源码：

    - 国内地址：[点击直达](https://gitee.com/CoderWanFeng/pydatav/tree/main/pydatav/resources/templates)
    - 国外地址：[点击直达](https://github.com/CoderWanFeng/pydatav/tree/main/pydatav/resources/templates)

# 开发环境

- 代码检查：pylint，配置文件：./conf/pylint.conf




# 交流群 & 免费课程



<p align="center" id='进群-banner'>
    <a target="_blank" href='http://www.python4office.cn/wechat-group/'>
    <img src="https://website-python-1300615378.cos.ap-nanjing.myqcloud.com/%E5%BC%95%E5%AF%BC%E8%B6%85%E9%93%BE%E6%8E%A5%2F%E6%8A%80%E6%9C%AF%E7%BE%A4.jpg" width="100%"/>
    </a>   
</p>


<p align="center" id='100本电子书-banner'>
    <a target="_blank" href='https://mp.weixin.qq.com/s/H3us6_7wg2QspGZfGtfDZw'>
    <img src="https://website-python-1300615378.cos.ap-nanjing.myqcloud.com/%E5%BC%95%E5%AF%BC%E8%B6%85%E9%93%BE%E6%8E%A5%2Febook.jpg" width="100%"/>
    </a>   
</p>



<p align="center" id='11个软件-banner'>
    <a target="_blank" href='https://mp.weixin.qq.com/s/uE1M8ESBQ3wJ_q-Cl1aNvg'>
    <img src="https://website-python-1300615378.cos.ap-nanjing.myqcloud.com/%E5%BC%95%E5%AF%BC%E8%B6%85%E9%93%BE%E6%8E%A5%2Fsoft-11.jpg" width="100%"/>
    </a>   
</p>


<p align="center" id='25个学习资源-banner'>
    <a target="_blank" href='https://mp.weixin.qq.com/s/_01V8I7rVkgvIIo7ygwwQA'>
    <img src="https://website-python-1300615378.cos.ap-nanjing.myqcloud.com/%E5%BC%95%E5%AF%BC%E8%B6%85%E9%93%BE%E6%8E%A5%2Fpy-25-source.jpg" width="100%"/>
    </a>   
</p>


